import React from 'react';
import CalendarChart from '../../src/plots/CalendarChart';
import { render, cleanup } from '@testing-library/react';

const MOCK_DATA = [
  { "date": "2017-05-01", "commits": 1, "month": 4, "day": 1, "week": "0" },
  { "date": "2017-05-02", "commits": 1, "month": 4, "day": 2, "week": "0" },
  { "date": "2017-05-03", "commits": 1, "month": 4, "day": 3, "week": "0" },
  { "date": "2017-05-04", "commits": 1, "month": 4, "day": 4, "week": "0" },
  { "date": "2017-05-05", "commits": 1, "month": 4, "day": 5, "week": "0" },
  { "date": "2017-05-06", "commits": 1, "month": 4, "day": 6, "week": "0" },
  { "date": "2017-05-07", "commits": 1, "month": 4, "day": 0, "week": "1" },
  { "date": "2017-05-08", "commits": 1, "month": 4, "day": 1, "week": "1" },
  { "date": "2017-05-09", "commits": 1, "month": 4, "day": 2, "week": "1" },
  { "date": "2017-05-10", "commits": 1, "month": 4, "day": 3, "week": "1" },
  { "date": "2017-05-11", "commits": 1, "month": 4, "day": 4, "week": "1" },
  { "date": "2017-05-12", "commits": 1, "month": 4, "day": 5, "week": "1" },
  { "date": "2017-05-13", "commits": 1, "month": 4, "day": 6, "week": "1" },
  { "date": "2017-05-14", "commits": 1, "month": 4, "day": 0, "week": "2" },
  { "date": "2017-05-15", "commits": 1, "month": 4, "day": 1, "week": "2" },
  { "date": "2017-05-16", "commits": 1, "month": 4, "day": 2, "week": "2" },
  { "date": "2017-05-17", "commits": 1, "month": 4, "day": 3, "week": "2" },
  { "date": "2017-05-18", "commits": 1, "month": 4, "day": 4, "week": "2" },
  { "date": "2017-05-19", "commits": 1, "month": 4, "day": 5, "week": "2" },
  { "date": "2017-05-20", "commits": 1, "month": 4, "day": 6, "week": "2" },
  { "date": "2017-05-21", "commits": 1, "month": 4, "day": 0, "week": "3" },
  { "date": "2017-05-22", "commits": 1, "month": 4, "day": 1, "week": "3" },
  { "date": "2017-05-23", "commits": 1, "month": 4, "day": 2, "week": "3" },
  { "date": "2017-05-24", "commits": 1, "month": 4, "day": 3, "week": "3" },
  { "date": "2017-05-25", "commits": 1, "month": 4, "day": 4, "week": "3", "lastWeek": true },
  { "date": "2017-05-26", "commits": 1, "month": 4, "day": 5, "week": "3", "lastWeek": true },
  { "date": "2017-05-27", "commits": 1, "month": 4, "day": 6, "week": "3", "lastWeek": true },
  { "date": "2017-05-28", "commits": 1, "month": 4, "day": 0, "week": "4", "lastWeek": true },
  { "date": "2017-05-29", "commits": 1, "month": 4, "day": 1, "week": "4", "lastWeek": true },
  { "date": "2017-05-30", "commits": 1, "month": 4, "day": 2, "week": "4", "lastWeek": true },
  { "date": "2017-05-31", "commits": 1, "month": 4, "day": 3, "week": "4", "lastWeek": true, "lastDay": true },
  { "date": "2017-06-01", "commits": 1, "month": 5, "day": 4, "week": "4" },
  { "date": "2017-06-02", "commits": 1, "month": 5, "day": 5, "week": "4" },
  { "date": "2017-06-03", "commits": 1, "month": 5, "day": 6, "week": "4" },
  { "date": "2017-06-04", "commits": 1, "month": 5, "day": 0, "week": "5" },
  { "date": "2017-06-05", "commits": 1, "month": 5, "day": 1, "week": "5" },
  { "date": "2017-06-06", "commits": 1, "month": 5, "day": 2, "week": "5" },
  { "date": "2017-06-07", "commits": 1, "month": 5, "day": 3, "week": "5" },
  { "date": "2017-06-08", "commits": 1, "month": 5, "day": 4, "week": "5" },
  { "date": "2017-06-09", "commits": 1, "month": 5, "day": 5, "week": "5" },
  { "date": "2017-06-10", "commits": 1, "month": 5, "day": 6, "week": "5" },
  { "date": "2017-06-11", "commits": 1, "month": 5, "day": 0, "week": "6" },
  { "date": "2017-06-12", "commits": 1, "month": 5, "day": 1, "week": "6" },
  { "date": "2017-06-13", "commits": 1, "month": 5, "day": 2, "week": "6" },
  { "date": "2017-06-14", "commits": 1, "month": 5, "day": 3, "week": "6" },
  { "date": "2017-06-15", "commits": 1, "month": 5, "day": 4, "week": "6" },
  { "date": "2017-06-16", "commits": 1, "month": 5, "day": 5, "week": "6" },
  { "date": "2017-06-17", "commits": 1, "month": 5, "day": 6, "week": "6" },
  { "date": "2017-06-18", "commits": 1, "month": 5, "day": 0, "week": "7" },
  { "date": "2017-06-19", "commits": 1, "month": 5, "day": 1, "week": "7" },
  { "date": "2017-06-20", "commits": 1, "month": 5, "day": 2, "week": "7" },
  { "date": "2017-06-21", "commits": 2, "month": 5, "day": 3, "week": "7" },
  { "date": "2017-06-22", "commits": 6, "month": 5, "day": 4, "week": "7" },
  { "date": "2017-06-23", "commits": 9, "month": 5, "day": 5, "week": "7" },
  { "date": "2017-06-24", "commits": 3, "month": 5, "day": 6, "week": "7", "lastWeek": true },
  { "date": "2017-06-25", "commits": 3, "month": 5, "day": 0, "week": "8", "lastWeek": true },
  { "date": "2017-06-26", "commits": 1, "month": 5, "day": 1, "week": "8", "lastWeek": true },
  { "date": "2017-06-27", "commits": 7, "month": 5, "day": 2, "week": "8", "lastWeek": true },
  { "date": "2017-06-28", "commits": 7, "month": 5, "day": 3, "week": "8", "lastWeek": true },
  { "date": "2017-06-29", "commits": 12, "month": 5, "day": 4, "week": "8", "lastWeek": true },
  { "date": "2017-06-30", "commits": 9, "month": 5, "day": 5, "week": "8", "lastWeek": true, "lastDay": true },
  { "date": "2017-07-01", "commits": 4, "month": 6, "day": 6, "week": "8" },
  { "date": "2017-07-02", "commits": 1, "month": 6, "day": 0, "week": "9" },
  { "date": "2017-07-03", "commits": 2, "month": 6, "day": 1, "week": "9" },
  { "date": "2017-07-04", "commits": 7, "month": 6, "day": 2, "week": "9" },
  { "date": "2017-07-05", "commits": 6, "month": 6, "day": 3, "week": "9" },
  { "date": "2017-07-06", "commits": 1, "month": 6, "day": 4, "week": "9" },
  { "date": "2017-07-07", "commits": 6, "month": 6, "day": 5, "week": "9" },
  { "date": "2017-07-08", "commits": 1, "month": 6, "day": 6, "week": "9" },
  { "date": "2017-07-09", "commits": 1, "month": 6, "day": 0, "week": "10" },
  { "date": "2017-07-10", "commits": 1, "month": 6, "day": 1, "week": "10" },
  { "date": "2017-07-11", "commits": 8, "month": 6, "day": 2, "week": "10" },
  { "date": "2017-07-12", "commits": 5, "month": 6, "day": 3, "week": "10" },
  { "date": "2017-07-13", "commits": 7, "month": 6, "day": 4, "week": "10" },
  { "date": "2017-07-14", "commits": 4, "month": 6, "day": 5, "week": "10" },
  { "date": "2017-07-15", "commits": 4, "month": 6, "day": 6, "week": "10" },
  { "date": "2017-07-16", "commits": 2, "month": 6, "day": 0, "week": "11" },
  { "date": "2017-07-17", "commits": 1, "month": 6, "day": 1, "week": "11" },
  { "date": "2017-07-18", "commits": 10, "month": 6, "day": 2, "week": "11" },
  { "date": "2017-07-19", "commits": 14, "month": 6, "day": 3, "week": "11" },
  { "date": "2017-07-20", "commits": 6, "month": 6, "day": 4, "week": "11" },
  { "date": "2017-07-21", "commits": 1, "month": 6, "day": 5, "week": "11" },
  { "date": "2017-07-22", "commits": 6, "month": 6, "day": 6, "week": "11" },
  { "date": "2017-07-23", "commits": 1, "month": 6, "day": 0, "week": "12" },
  { "date": "2017-07-24", "commits": 1, "month": 6, "day": 1, "week": "12" },
  { "date": "2017-07-25", "commits": 1, "month": 6, "day": 2, "week": "12", "lastWeek": true },
  { "date": "2017-07-26", "commits": 1, "month": 6, "day": 3, "week": "12", "lastWeek": true },
  { "date": "2017-07-27", "commits": 9, "month": 6, "day": 4, "week": "12", "lastWeek": true },
  { "date": "2017-07-28", "commits": 1, "month": 6, "day": 5, "week": "12", "lastWeek": true },
  { "date": "2017-07-29", "commits": 15, "month": 6, "day": 6, "week": "12", "lastWeek": true },
  { "date": "2017-07-30", "commits": 1, "month": 6, "day": 0, "week": "13", "lastWeek": true },
  { "date": "2017-07-31", "commits": 1, "month": 6, "day": 1, "week": "13", "lastWeek": true, "lastDay": true },
  { "date": "2017-08-01", "commits": 15, "month": 7, "day": 2, "week": "13" },
  { "date": "2017-08-02", "commits": 11, "month": 7, "day": 3, "week": "13" },
  { "date": "2017-08-03", "commits": 3, "month": 7, "day": 4, "week": "13" },
  { "date": "2017-08-04", "commits": 6, "month": 7, "day": 5, "week": "13" },
  { "date": "2017-08-05", "commits": 1, "month": 7, "day": 6, "week": "13" },
  { "date": "2017-08-06", "commits": 4, "month": 7, "day": 0, "week": "14" },
  { "date": "2017-08-07", "commits": 1, "month": 7, "day": 1, "week": "14" },
  { "date": "2017-08-08", "commits": 10, "month": 7, "day": 2, "week": "14" },
  { "date": "2017-08-09", "commits": 11, "month": 7, "day": 3, "week": "14" },
  { "date": "2017-08-10", "commits": 8, "month": 7, "day": 4, "week": "14" },
  { "date": "2017-08-11", "commits": 12, "month": 7, "day": 5, "week": "14" },
  { "date": "2017-08-12", "commits": 8, "month": 7, "day": 6, "week": "14" },
  { "date": "2017-08-13", "commits": 2, "month": 7, "day": 0, "week": "15" },
  { "date": "2017-08-14", "commits": 1, "month": 7, "day": 1, "week": "15" },
  { "date": "2017-08-15", "commits": 18, "month": 7, "day": 2, "week": "15" },
  { "date": "2017-08-16", "commits": 21, "month": 7, "day": 3, "week": "15" },
  { "date": "2017-08-17", "commits": 7, "month": 7, "day": 4, "week": "15" },
  { "date": "2017-08-18", "commits": 10, "month": 7, "day": 5, "week": "15" },
  { "date": "2017-08-19", "commits": 8, "month": 7, "day": 6, "week": "15" },
  { "date": "2017-08-20", "commits": 1, "month": 7, "day": 0, "week": "16" },
  { "date": "2017-08-21", "commits": 1, "month": 7, "day": 1, "week": "16" },
  { "date": "2017-08-22", "commits": 1, "month": 7, "day": 2, "week": "16" },
  { "date": "2017-08-23", "commits": 7, "month": 7, "day": 3, "week": "16" },
  { "date": "2017-08-24", "commits": 11, "month": 7, "day": 4, "week": "16" },
  { "date": "2017-08-25", "commits": 3, "month": 7, "day": 5, "week": "16", "lastWeek": true },
  { "date": "2017-08-26", "commits": 3, "month": 7, "day": 6, "week": "16", "lastWeek": true },
  { "date": "2017-08-27", "commits": 1, "month": 7, "day": 0, "week": "17", "lastWeek": true },
  { "date": "2017-08-28", "commits": 2, "month": 7, "day": 1, "week": "17", "lastWeek": true },
  { "date": "2017-08-29", "commits": 7, "month": 7, "day": 2, "week": "17", "lastWeek": true },
  { "date": "2017-08-30", "commits": 20, "month": 7, "day": 3, "week": "17", "lastWeek": true },
  { "date": "2017-08-31", "commits": 15, "month": 7, "day": 4, "week": "17", "lastWeek": true, "lastDay": true },
  { "date": "2017-09-01", "commits": 1, "month": 8, "day": 5, "week": "17" },
  { "date": "2017-09-02", "commits": 4, "month": 8, "day": 6, "week": "17" },
  { "date": "2017-09-03", "commits": 1, "month": 8, "day": 0, "week": "18" },
  { "date": "2017-09-04", "commits": 1, "month": 8, "day": 1, "week": "18" },
  { "date": "2017-09-05", "commits": 8, "month": 8, "day": 2, "week": "18" },
  { "date": "2017-09-06", "commits": 6, "month": 8, "day": 3, "week": "18" },
  { "date": "2017-09-07", "commits": 5, "month": 8, "day": 4, "week": "18" },
  { "date": "2017-09-08", "commits": 1, "month": 8, "day": 5, "week": "18" },
  { "date": "2017-09-09", "commits": 25, "month": 8, "day": 6, "week": "18" },
  { "date": "2017-09-10", "commits": 1, "month": 8, "day": 0, "week": "19" },
  { "date": "2017-09-11", "commits": 1, "month": 8, "day": 1, "week": "19" },
  { "date": "2017-09-12", "commits": 1, "month": 8, "day": 2, "week": "19" },
  { "date": "2017-09-13", "commits": 9, "month": 8, "day": 3, "week": "19" },
  { "date": "2017-09-14", "commits": 1, "month": 8, "day": 4, "week": "19" },
  { "date": "2017-09-15", "commits": 1, "month": 8, "day": 5, "week": "19" },
  { "date": "2017-09-16", "commits": 4, "month": 8, "day": 6, "week": "19" },
  { "date": "2017-09-17", "commits": 1, "month": 8, "day": 0, "week": "20" },
  { "date": "2017-09-18", "commits": 1, "month": 8, "day": 1, "week": "20" },
  { "date": "2017-09-19", "commits": 4, "month": 8, "day": 2, "week": "20" },
  { "date": "2017-09-20", "commits": 8, "month": 8, "day": 3, "week": "20" },
  { "date": "2017-09-21", "commits": 10, "month": 8, "day": 4, "week": "20" },
  { "date": "2017-09-22", "commits": 9, "month": 8, "day": 5, "week": "20" },
  { "date": "2017-09-23", "commits": 5, "month": 8, "day": 6, "week": "20" },
  { "date": "2017-09-24", "commits": 1, "month": 8, "day": 0, "week": "21", "lastWeek": true },
  { "date": "2017-09-25", "commits": 1, "month": 8, "day": 1, "week": "21", "lastWeek": true },
  { "date": "2017-09-26", "commits": 1, "month": 8, "day": 2, "week": "21", "lastWeek": true },
  { "date": "2017-09-27", "commits": 7, "month": 8, "day": 3, "week": "21", "lastWeek": true },
  { "date": "2017-09-28", "commits": 13, "month": 8, "day": 4, "week": "21", "lastWeek": true },
  { "date": "2017-09-29", "commits": 1, "month": 8, "day": 5, "week": "21", "lastWeek": true },
  { "date": "2017-09-30", "commits": 7, "month": 8, "day": 6, "week": "21", "lastWeek": true },
  { "date": "2017-10-01", "commits": 1, "month": 9, "day": 0, "week": "22" },
  { "date": "2017-10-02", "commits": 1, "month": 9, "day": 1, "week": "22" },
  { "date": "2017-10-03", "commits": 7, "month": 9, "day": 2, "week": "22" },
  { "date": "2017-10-04", "commits": 2, "month": 9, "day": 3, "week": "22" },
  { "date": "2017-10-05", "commits": 14, "month": 9, "day": 4, "week": "22" },
  { "date": "2017-10-06", "commits": 9, "month": 9, "day": 5, "week": "22" },
  { "date": "2017-10-07", "commits": 12, "month": 9, "day": 6, "week": "22" },
  { "date": "2017-10-08", "commits": 1, "month": 9, "day": 0, "week": "23" },
  { "date": "2017-10-09", "commits": 1, "month": 9, "day": 1, "week": "23" },
  { "date": "2017-10-10", "commits": 13, "month": 9, "day": 2, "week": "23" },
  { "date": "2017-10-11", "commits": 12, "month": 9, "day": 3, "week": "23" },
  { "date": "2017-10-12", "commits": 1, "month": 9, "day": 4, "week": "23" },
  { "date": "2017-10-13", "commits": 1, "month": 9, "day": 5, "week": "23" },
  { "date": "2017-10-14", "commits": 1, "month": 9, "day": 6, "week": "23" },
  { "date": "2017-10-15", "commits": 1, "month": 9, "day": 0, "week": "24" },
  { "date": "2017-10-16", "commits": 1, "month": 9, "day": 1, "week": "24" },
  { "date": "2017-10-17", "commits": 1, "month": 9, "day": 2, "week": "24" },
  { "date": "2017-10-18", "commits": 1, "month": 9, "day": 3, "week": "24" },
  { "date": "2017-10-19", "commits": 1, "month": 9, "day": 4, "week": "24" },
  { "date": "2017-10-20", "commits": 1, "month": 9, "day": 5, "week": "24" },
  { "date": "2017-10-21", "commits": 1, "month": 9, "day": 6, "week": "24" },
  { "date": "2017-10-22", "commits": 1, "month": 9, "day": 0, "week": "25" },
  { "date": "2017-10-23", "commits": 1, "month": 9, "day": 1, "week": "25" },
  { "date": "2017-10-24", "commits": 10, "month": 9, "day": 2, "week": "25" },
  { "date": "2017-10-25", "commits": 4, "month": 9, "day": 3, "week": "25" },
  { "date": "2017-10-26", "commits": 7, "month": 9, "day": 4, "week": "25" },
  { "date": "2017-10-27", "commits": 3, "month": 9, "day": 5, "week": "25" },
  { "date": "2017-10-28", "commits": 14, "month": 9, "day": 6, "week": "25" },
  { "date": "2017-10-29", "commits": 1, "month": 9, "day": 0, "week": "26" },
  { "date": "2017-10-30", "commits": 1, "month": 9, "day": 1, "week": "26" },
  { "date": "2017-10-31", "commits": 5, "month": 9, "day": 2, "week": "26", "lastDay": true }
]
;

describe('Plots-CalendarChart', () => {
  test('1.0日历图', () => {
    let chart = null;
    // @ts-ignore
    render(<CalendarChart
      data={MOCK_DATA}
      title={{
        visible: true,
        text: '日历图',
      }}
      dateField='date'
      valueField='commits'
      dateRange={['2017-05-01', '2017-10-31']}
      colors='#BAE7FF-#1890FF-#0050B3'
      padding='auto'
      xAxis={{
        title: {
          text: '月份',
        },
      }}
      colorField="commits"
      yAxis={{
        title: null,
      }}
      meta={{
        day: {
          type: 'cat'
        }
      }}
      onGetG2Instance={
        (c) => chart = c
      }
    />)
    expect(chart.options).toMatchSnapshot();
    // cleanup();
  });
  test('新版日历图', () => {
    let chart = null;
    // @ts-ignore
    render(<CalendarChart
      data={MOCK_DATA}
      title={{
        visible: true,
        text: '日历图',
      }}
      xField="week"
      yField="day"
      colorField= 'commits'
      color= '#BAE7FF-#1890FF-#0050B3'
      reflect="y"
      shape= 'boundary-polygon'
      dateField='date'
      meta={{
        day: {
          type: 'cat'
        }
      }}
      onGetG2Instance={
        (c) => chart = c
      }
    />)
    expect(chart.options).toMatchSnapshot();
    // cleanup();
  });
})
